@@ -533,12 +533,12 @@ calculate.overlap <- function(x) {
 
 		# calculate overlaps
 		a5 = nabc;
-		a2 = nab[-which(nab %in% a5)];
-		a4 = nac[-which(nac %in% a5)];
-		a6 = nbc[-which(nbc %in% a5)];
-		a1 = A[-which(A %in% c(a2,a4,a5))];
-		a3 = B[-which(B %in% c(a2,a5,a6))];
-		a7 = C[-which(C %in% c(a4,a5,a6))];
+		a2 = nab[which(!nab %in% a5)];
+		a4 = nac[which(!nac %in% a5)];
+		a6 = nbc[which(!nbc %in% a5)];
+		a1 = A[which(!A %in% c(a2,a4,a5))];
+		a3 = B[which(!B %in% c(a2,a5,a6))];
+		a7 = C[which(!C %in% c(a4,a5,a6))];
 
 		overlap <- list(
 			a5 = a5,
@@ -575,20 +575,20 @@ calculate.overlap <- function(x) {
 
 		# calculate overlaps
 		a6  = n1234;
-		a12 = n123[-which(n123 %in% a6)];
-		a11 = n124[-which(n124 %in% a6)];
-		a5  = n134[-which(n134 %in% a6)];
-		a7  = n234[-which(n234 %in% a6)];
-		a15 = n12[-which(n12 %in% c(a6,a11,a12))];
-		a4  = n13[-which(n13 %in% c(a6,a5,a12))];
-		a10 = n14[-which(n14 %in% c(a6,a5,a11))];
-		a13 = n23[-which(n23 %in% c(a6,a7,a12))];
-		a8  = n24[-which(n24 %in% c(a6,a7,a11))];
-		a2  = n34[-which(n34 %in% c(a6,a5,a7))];
-		a9  = A[-which(A %in% c(a4,a5,a6,a10,a11,a12,a15))];
-		a14 = B[-which(B %in% c(a6,a7,a8,a11,a12,a13,a15))];
-		a1  = C[-which(C %in% c(a2,a4,a5,a6,a7,a12,a13))];
-		a3  = D[-which(D %in% c(a2,a5,a6,a7,a8,a10,a11))];
+		a12 = n123[which(!n123 %in% a6)];
+		a11 = n124[which(!n124 %in% a6)];
+		a5  = n134[which(!n134 %in% a6)];
+		a7  = n234[which(!n234 %in% a6)];
+		a15 = n12[which(!n12 %in% c(a6,a11,a12))];
+		a4  = n13[which(!n13 %in% c(a6,a5,a12))];
+		a10 = n14[which(!n14 %in% c(a6,a5,a11))];
+		a13 = n23[which(!n23 %in% c(a6,a7,a12))];
+		a8  = n24[which(!n24 %in% c(a6,a7,a11))];
+		a2  = n34[which(!n34 %in% c(a6,a5,a7))];
+		a9  = A[which(!A %in% c(a4,a5,a6,a10,a11,a12,a15))];
+		a14 = B[which(!B %in% c(a6,a7,a8,a11,a12,a13,a15))];
+		a1  = C[which(!C %in% c(a2,a4,a5,a6,a7,a12,a13))];
+		a3  = D[which(!D %in% c(a2,a5,a6,a7,a8,a10,a11))];
 
 		overlap <- list(
 			a6  = a6,
@@ -649,36 +649,36 @@ calculate.overlap <- function(x) {
 
 		# calculate overlaps
 		a31  = n12345;
-		a30 = n1234[-which(n1234 %in% a31)];
-		a29 = n1235[-which(n1235 %in% a31)];
-		a28 = n1245[-which(n1245 %in% a31)];
-		a27 = n1345[-which(n1345 %in% a31)];
-		a26 = n2345[-which(n2345 %in% a31)];
-		a25 = n245[-which(n245 %in% c(a26,a28,a31))];
-		a24 = n234[-which(n234 %in% c(a26,a30,a31))];
-		a23 = n134[-which(n134 %in% c(a27,a30,a31))];
-		a22 = n123[-which(n123 %in% c(a29,a30,a31))];
-		a21 = n235[-which(n235 %in% c(a26,a29,a31))];
-		a20 = n125[-which(n125 %in% c(a28,a29,a31))];
-		a19 = n124[-which(n124 %in% c(a28,a30,a31))];
-		a18 = n145[-which(n145 %in% c(a27,a28,a31))];
-		a17 = n135[-which(n135 %in% c(a27,a29,a31))];
-		a16 = n345[-which(n345 %in% c(a26,a27,a31))];
-		a15 = n45[-which(n45 %in% c(a18,a25,a16,a28,a27,a26,a31))];
-		a14 = n24[-which(n24 %in% c(a19,a24,a25,a30,a28,a26,a31))];
-		a13 = n34[-which(n34 %in% c(a16,a23,a24,a26,a27,a30,a31))];
-		a12 = n13[-which(n13 %in% c(a17,a22,a23,a27,a29,a30,a31))];
-		a11 = n23[-which(n23 %in% c(a21,a22,a24,a26,a29,a30,a31))];
-		a10 = n25[-which(n25 %in% c(a20,a21,a25,a26,a28,a29,a31))];
-		a9 = n12[-which(n12 %in% c(a19,a20,a22,a28,a29,a30,a31))];
-		a8 = n14[-which(n14 %in% c(a18,a19,a23,a27,a28,a30,a31))];
-		a7 = n15[-which(n15 %in% c(a17,a18,a20,a27,a28,a29,a31))];
-		a6 = n35[-which(n35 %in% c(a16,a17,a21,a26,a27,a29,a31))];
-		a5 = E[-which(E %in% c(a6,a7,a15,a16,a17,a18,a25,a26,a27,a28,a31,a20,a29,a21,a10))];
-		a4 = D[-which(D %in% c(a13,a14,a15,a16,a23,a24,a25,a26,a27,a28,a31,a18,a19,a8,a30))];
-		a3 = C[-which(C %in% c(a21,a11,a12,a13,a29,a22,a23,a24,a30,a31,a26,a27,a16,a6,a17))];
-		a2 = B[-which(B %in% c(a9,a10,a19,a20,a21,a11,a28,a29,a31,a22,a30,a26,a25,a24,a14))];
-		a1 = A[-which(A %in% c(a7,a8,a18,a17,a19,a9,a27,a28,a31,a20,a30,a29,a22,a23,a12))];
+		a30 = n1234[which(!n1234 %in% a31)];
+		a29 = n1235[which(!n1235 %in% a31)];
+		a28 = n1245[which(!n1245 %in% a31)];
+		a27 = n1345[which(!n1345 %in% a31)];
+		a26 = n2345[which(!n2345 %in% a31)];
+		a25 = n245[which(!n245 %in% c(a26,a28,a31))];
+		a24 = n234[which(!n234 %in% c(a26,a30,a31))];
+		a23 = n134[which(!n134 %in% c(a27,a30,a31))];
+		a22 = n123[which(!n123 %in% c(a29,a30,a31))];
+		a21 = n235[which(!n235 %in% c(a26,a29,a31))];
+		a20 = n125[which(!n125 %in% c(a28,a29,a31))];
+		a19 = n124[which(!n124 %in% c(a28,a30,a31))];
+		a18 = n145[which(!n145 %in% c(a27,a28,a31))];
+		a17 = n135[which(!n135 %in% c(a27,a29,a31))];
+		a16 = n345[which(!n345 %in% c(a26,a27,a31))];
+		a15 = n45[which(!n45 %in% c(a18,a25,a16,a28,a27,a26,a31))];
+		a14 = n24[which(!n24 %in% c(a19,a24,a25,a30,a28,a26,a31))];
+		a13 = n34[which(!n34 %in% c(a16,a23,a24,a26,a27,a30,a31))];
+		a12 = n13[which(!n13 %in% c(a17,a22,a23,a27,a29,a30,a31))];
+		a11 = n23[which(!n23 %in% c(a21,a22,a24,a26,a29,a30,a31))];
+		a10 = n25[which(!n25 %in% c(a20,a21,a25,a26,a28,a29,a31))];
+		a9 = n12[which(!n12 %in% c(a19,a20,a22,a28,a29,a30,a31))];
+		a8 = n14[which(!n14 %in% c(a18,a19,a23,a27,a28,a30,a31))];
+		a7 = n15[which(!n15 %in% c(a17,a18,a20,a27,a28,a29,a31))];
+		a6 = n35[which(!n35 %in% c(a16,a17,a21,a26,a27,a29,a31))];
+		a5 = E[which(!E %in% c(a6,a7,a15,a16,a17,a18,a25,a26,a27,a28,a31,a20,a29,a21,a10))];
+		a4 = D[which(!D %in% c(a13,a14,a15,a16,a23,a24,a25,a26,a27,a28,a31,a18,a19,a8,a30))];
+		a3 = C[which(!C %in% c(a21,a11,a12,a13,a29,a22,a23,a24,a30,a31,a26,a27,a16,a6,a17))];
+		a2 = B[which(!B %in% c(a9,a10,a19,a20,a21,a11,a28,a29,a31,a22,a30,a26,a25,a24,a14))];
+		a1 = A[which(!A %in% c(a7,a8,a18,a17,a19,a9,a27,a28,a31,a20,a30,a29,a22,a23,a12))];
 
 		overlap <- list(
 			a31  = a31,
